@@ -1,22 +1,6 @@
 /*
- * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.  
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 #include "dbuiltiniconengine.h"
 
@@ -217,12 +201,11 @@ void DBuiltinIconEngine::paint(QPainter *painter, const QRect &rect,
 {
     ensureLoaded();
 
-    QSize pixmapSize = rect.size();
-    qreal scale = 1;
-    if (painter->device())
-        scale = painter->device()->devicePixelRatioF();
+    qreal scale = 1.0;
+    if (qApp->testAttribute(Qt::AA_UseHighDpiPixmaps))
+        scale = painter->device() ? painter->device()->devicePixelRatioF() : qApp->devicePixelRatio();
 
-    pixmapSize *= scale;
+    QSize pixmapSize = rect.size() * scale;
 
     QIconLoaderEngineEntry *entry = QIconLoaderEngine::entryForSize(m_info, pixmapSize);
     if (!entry)
