@@ -1,30 +1,17 @@
 /*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2017-2022 UnionTech Software Technology Co., Ltd.  
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
-
 #ifndef QDEEPINFILEDIALOGHELPER_H
 #define QDEEPINFILEDIALOGHELPER_H
 
 #include <qpa/qplatformdialoghelper.h>
 
 #include <QPointer>
+#include <QEventLoop>
 
 QT_BEGIN_NAMESPACE
 
-class QFileDialog;
 class ComDeepinFilemanagerFiledialogInterface;
 typedef ComDeepinFilemanagerFiledialogInterface DFileDialogHandle;
 class ComDeepinFilemanagerFiledialogmanagerInterface;
@@ -47,7 +34,7 @@ public:
     bool defaultNameFilterDisables() const Q_DECL_OVERRIDE;
     void setDirectory(const QUrl &directory) Q_DECL_OVERRIDE;
     QUrl directory() const Q_DECL_OVERRIDE;
-    void selectFile(const QUrl &fileUrl) Q_DECL_OVERRIDE;
+    void selectFile(const QUrl &filename) Q_DECL_OVERRIDE;
     QList<QUrl> selectedFiles() const Q_DECL_OVERRIDE;
     void setFilter() Q_DECL_OVERRIDE;
     void selectNameFilter(const QString &filter) Q_DECL_OVERRIDE;
@@ -55,17 +42,20 @@ public:
 
     static void initDBusFileDialogManager();
     static bool iAmFileDialogDBusServer();
-
+protected:
+    void onApplicationStateChanged(Qt::ApplicationState state);
+    void onWindowActiveChanged();
 private:
-    mutable QPointer<DFileDialogHandle> nativeDialog;
+    mutable QPointer<DFileDialogHandle> filedlgInterface;
     mutable QPointer<QWindow> auxiliaryWindow;
-    mutable QPointer<QFileDialog> qtDialog;
     QPointer<QWindow> activeWindow;
-    QPointer<QFileDialog> sourceDialog;
+    QPointer<QObject> sourceDialog;
+    QPointer<QEventLoop> execLoop;
     static DFileDialogManager *manager;
 
     void ensureDialog() const;
     void applyOptions();
+    void hideAuxiliaryWindow() const;
 
     friend class QDeepinTheme;
 };
