@@ -1,25 +1,12 @@
 /*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.  
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
-
 #include "qdeepintheme.h"
 #include "qdeepinfiledialoghelper.h"
-#include "diconproxyengine.h"
 #include "filedialogmanager_interface.h"
 #include "dthemesettings.h"
+#include "../3rdparty/qdbustrayicon_p.h"
 
 #include <DGuiApplicationHelper>
 #include <DPlatformTheme>
@@ -43,7 +30,6 @@
 #undef signals
 #include <X11/Xlib.h>
 
-
 DGUI_USE_NAMESPACE
 
 #if XDG_ICON_VERSION_MAR >= 3
@@ -70,6 +56,19 @@ DThemeSettings *QDeepinTheme::m_settings = 0;
 
 extern void updateXdgIconSystemTheme();
 
+static bool isDBusTrayAvailable() {
+    static bool dbusTrayAvailable = false;
+    static bool dbusTrayAvailableKnown = false;
+    if (!dbusTrayAvailableKnown) {
+        thirdparty::QDBusMenuConnection conn;
+        if (conn.isStatusNotifierHostRegistered())
+            dbusTrayAvailable = true;
+        dbusTrayAvailableKnown = true;
+        qCDebug(thirdparty::dLcTray) << "D-Bus tray available:" << dbusTrayAvailable;
+    }
+    return dbusTrayAvailable;
+}
+
 static void onIconThemeSetCallback()
 {
     QIconLoader::instance()->updateSystemTheme();
@@ -492,29 +491,36 @@ static QIconEnginePlugin *getIconEngineFactory(const QString &key)
     static QFactoryLoader loader(QIconEngineFactoryInterface_iid, QLatin1String("/iconengines"), Qt::CaseSensitive);
     int index = loader.indexOf(key);
 
-    if (index != -1) {
+    if (index != -1)
         return qobject_cast<QIconEnginePlugin *>(loader.instance(index));
-    }
 
     return nullptr;
 }
 
-static QIconEngine *createBuiltinIconEngine(const QString &iconName)
+static QIconEngine *createIconEngineWithKey(const QString &iconName, const QString &key)
 {
-    static QIconEnginePlugin *plugin = getIconEngineFactory(QStringLiteral("DBuiltinIconEngine"));
+    QIconEnginePlugin *plugin = getIconEngineFactory(key);
+    if (!plugin)
+        return nullptr;
 
-    return plugin ? plugin->create(iconName) : nullptr;
-}
+    QIconEngine *iconEngine = plugin->create(iconName);
+    if (!iconEngine)
+        return nullptr;
 
-static QIconEngine *createXdgProxyIconEngine(const QString &iconName)
-{
-    static QIconEnginePlugin *plugin = getIconEngineFactory(QStringLiteral("XdgIconProxyEngine"));
+    if (iconEngine->isNull()) {
+        delete iconEngine;
+        return nullptr;
+    }
 
-    return plugin ? plugin->create(iconName) : nullptr;
+    return iconEngine;
 }
 
 QIconEngine *QDeepinTheme::createIconEngine(const QString &iconName) const
 {
+    QIconEngine *engine = createIconEngineWithKey(iconName, "DIconProxyEngine");
+    if (engine)
+        return engine;
+
 #ifdef DTHEMED_ICON_LOOKUP
     if (iconName.contains("/"))
         // handle Qt-standard paths.
@@ -524,25 +530,8 @@ QIconEngine *QDeepinTheme::createIconEngine(const QString &iconName) const
 #elif XDG_ICON_VERSION_MAR < 3
     return XdgIconEngineCreator::create(iconName);
 #else
-    static QSet<QString> non_builtin_icon_cache;
 
-    if (!non_builtin_icon_cache.contains(iconName)) {
-        // 记录下来此种类型的icon为内置图标
-        // 因此，此处添加的缓存不考虑更新
-        // 优先使用内置图标
-        if (QIconEngine *engine = createBuiltinIconEngine(iconName)) {
-            if (engine->isNull()) {
-                non_builtin_icon_cache.insert(iconName);
-                delete engine;
-            } else {
-                return engine;
-            }
-        } else {
-            non_builtin_icon_cache.insert(iconName);
-        }
-    }
-
-    return createXdgProxyIconEngine(iconName);
+    return QGenericUnixTheme::createIconEngine(iconName);
 #endif
 }
 
@@ -567,6 +556,15 @@ QPixmap QDeepinTheme::fileIconPixmap(const QFileInfo &fileInfo, const QSizeF &si
 }
 #endif
 
+#if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
+QPlatformSystemTrayIcon *QDeepinTheme::createPlatformSystemTrayIcon() const
+{
+    if (isDBusTrayAvailable())
+        return new thirdparty::QDBusTrayIcon();
+    return nullptr;
+}
+#endif
+
 static DPlatformTheme *appTheme()
 {
     static QPointer<DPlatformTheme> theme;
@@ -654,12 +652,14 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
                 font_size = 10.5;
             }
 
-            static QFont font = QFont(QString());
+            static QScopedPointer<QFont> sysFont;
 
-            font.setFamily(font_name);
-            font.setPointSizeF(font_size);
+            // We need to re-contruct a new QFont each time, inorder to refresh font dpi
+            sysFont.reset(new QFont(QString()));
+            sysFont->setFamily(font_name);
+            sysFont->setPointSizeF(font_size);
 
-            return &font;
+            return sysFont.data();
         }
 
         break;
@@ -677,12 +677,14 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
                 font_size = 10.5;
             }
 
-            static QFont font = QFont(QString());
+            static QScopedPointer<QFont> fixedFont;
 
-            font.setFamily(font_name);
-            font.setPointSizeF(font_size);
+            // We need to re-contruct a new QFont each time, inorder to refresh font dpi
+            fixedFont.reset(new QFont(QString()));
+            fixedFont->setFamily(font_name);
+            fixedFont->setPointSizeF(font_size);
 
-            return &font;
+            return fixedFont.data();
         }
 
         break;
