@@ -1,20 +1,7 @@
 /*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.  
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
-
 #include "style.h"
 #include "commonhelper.h"
 #include "paletteextended.h"
@@ -280,9 +267,9 @@ bool Style::drawMenuItemControl(const QStyleOption *option, QPainter *painter, c
             int dim = (menuItem->rect.height() - 4) / 2;
 //            PrimitiveElement arrow;
 //            arrow = option->direction == Qt::RightToLeft ? PE_IndicatorArrowLeft : PE_IndicatorArrowRight;
-            int xposItem = menuItem->rect.left() + menuItem->rect.width() - 3 - dim;
+            int xpos = menuItem->rect.left() + menuItem->rect.width() - 3 - dim;
             QRect  vSubMenuRect = visualRect(option->direction, menuItem->rect,
-                                             QRect(xposItem, menuItem->rect.top() + menuItem->rect.height() / 2 - dim / 2, dim, dim));
+                                             QRect(xpos, menuItem->rect.top() + menuItem->rect.height() / 2 - dim / 2, dim, dim));
             QStyleOptionMenuItem newMI = *menuItem;
             newMI.rect = vSubMenuRect;
             if (selected)
